@@ -180,7 +180,9 @@ class LinkedinScraper:
                     to_block = [
                         'li/track',
                         'realtime.www.linkedin.com/realtime',
-                        'platform.linkedin.com/litms/utag/voyager-web-jobs',
+                        'platform.linkedin.com/litms',
+                        'linkedin.com/sensorCollect',
+                        'linkedin.com/pixel/tracking',
                     ]
 
                     if any([e in request.url for e in to_block]):
